@@ -53,4 +53,32 @@ def test_postal_code_names():
 
     res = CP._postal_code_names("t.cp")
     assert res["001"] != "MM"
-    os.unlink("t.cp")    
\ No newline at end of file
+    os.unlink("t.cp")  
+
+
+def test_travel():
+    from text_models.place import Travel, CP
+    travel = Travel(window=3)
+    assert len(travel._days) == 3
+    print(travel.num_users)
+    assert isinstance(travel._cp, CP)
+
+
+def test_travel_displacement():
+    from text_models.place import Travel, CP
+    travel = Travel(window=3)
+    assert len(travel._days) == 3
+    output = travel.displacement()
+    for v in output.values():
+        assert len(v) == 3
+
+
+def test_travel_dates():
+    from text_models.place import Travel, CP
+    from datetime import datetime
+    travel = Travel(datetime(year=2020, month=4, day=4),
+                    window=4)
+    print(travel.dates[-1].day, 4)
+    assert travel.dates[-1].day == 4
+    print(travel.dates[0].day, 1)
+    assert travel.dates[0].day == 1
\ No newline at end of file
